@@ -14,10 +14,21 @@
 # ==============================================================================
 """Flower main package."""
 
+import sys
 
-from . import client, server
+from . import client, server, simulation
 
 __all__ = [
     "client",
     "server",
+    "simulation",
 ]
+
+# pylint: disable=import-error, no-name-in-module
+if sys.version_info < (3, 8):
+    import importlib_metadata
+else:
+    import importlib.metadata as importlib_metadata
+# pylint: enable=import-error, no-name-in-module
+
+__version__: str = importlib_metadata.version(__name__)
