@@ -17,8 +17,15 @@
 
 from typing import Tuple
 
-from flwr.client.client import Client, has_get_properties
+from flwr.client.client import (
+    Client,
+    has_evaluate,
+    has_fit,
+    has_get_parameters,
+    has_get_properties,
+)
 from flwr.common import serde, typing
+from flwr.common.typing import Parameters
 from flwr.proto.transport_pb2 import ClientMessage, Reason, ServerMessage
 
 # pylint: disable=missing-function-docstring
@@ -50,13 +57,13 @@ def handle(
         reconnect later (False).
     """
     field = server_msg.WhichOneof("msg")
-    if field == "reconnect":
-        disconnect_msg, sleep_duration = _reconnect(server_msg.reconnect)
+    if field == "reconnect_ins":
+        disconnect_msg, sleep_duration = _reconnect(server_msg.reconnect_ins)
         return disconnect_msg, sleep_duration, False
-    if field == "properties_ins":
-        return _get_properties(client, server_msg.properties_ins), 0, True
-    if field == "get_parameters":
-        return _get_parameters(client), 0, True
+    if field == "get_properties_ins":
+        return _get_properties(client, server_msg.get_properties_ins), 0, True
+    if field == "get_parameters_ins":
+        return _get_parameters(client, server_msg.get_parameters_ins), 0, True
     if field == "fit_ins":
         return _fit(client, server_msg.fit_ins), 0, True
     if field == "evaluate_ins":
@@ -65,52 +72,85 @@ def handle(
 
 
 def _reconnect(
-    reconnect_msg: ServerMessage.Reconnect,
+    reconnect_msg: ServerMessage.ReconnectIns,
 ) -> Tuple[ClientMessage, int]:
-    # Determine the reason for sending Disconnect message
+    # Determine the reason for sending DisconnectRes message
     reason = Reason.ACK
     sleep_duration = None
     if reconnect_msg.seconds is not None:
         reason = Reason.RECONNECT
         sleep_duration = reconnect_msg.seconds
-    # Build Disconnect message
-    disconnect = ClientMessage.Disconnect(reason=reason)
-    return ClientMessage(disconnect=disconnect), sleep_duration
+    # Build DisconnectRes message
+    disconnect_res = ClientMessage.DisconnectRes(reason=reason)
+    return ClientMessage(disconnect_res=disconnect_res), sleep_duration
 
 
 def _get_properties(
-    client: Client, properties_msg: ServerMessage.PropertiesIns
+    client: Client, get_properties_msg: ServerMessage.GetPropertiesIns
 ) -> ClientMessage:
     # Check if client overrides get_properties
     if not has_get_properties(client=client):
         # If client does not override get_properties, don't call it
-        properties_res = typing.PropertiesRes(
+        get_properties_res = typing.GetPropertiesRes(
             status=typing.Status(
-                code=typing.Code.GET_PARAMETERS_NOT_IMPLEMENTED,
-                message="Client does not implement get_properties",
+                code=typing.Code.GET_PROPERTIES_NOT_IMPLEMENTED,
+                message="Client does not implement `get_properties`",
             ),
             properties={},
         )
-        properties_res_proto = serde.properties_res_to_proto(properties_res)
-        return ClientMessage(properties_res=properties_res_proto)
+        get_properties_res_proto = serde.get_properties_res_to_proto(get_properties_res)
+        return ClientMessage(get_properties_res=get_properties_res_proto)
 
     # Deserialize get_properties instruction
-    properties_ins = serde.properties_ins_from_proto(properties_msg)
-    # Request for properties
-    properties_res = client.get_properties(properties_ins)
+    get_properties_ins = serde.get_properties_ins_from_proto(get_properties_msg)
+    # Request properties
+    get_properties_res = client.get_properties(get_properties_ins)
     # Serialize response
-    properties_res_proto = serde.properties_res_to_proto(properties_res)
-    return ClientMessage(properties_res=properties_res_proto)
+    get_properties_res_proto = serde.get_properties_res_to_proto(get_properties_res)
+    return ClientMessage(get_properties_res=get_properties_res_proto)
 
 
-def _get_parameters(client: Client) -> ClientMessage:
-    # No need to deserialize get_parameters_msg (it's empty)
-    parameters_res = client.get_parameters()
-    parameters_res_proto = serde.parameters_res_to_proto(parameters_res)
-    return ClientMessage(parameters_res=parameters_res_proto)
+def _get_parameters(
+    client: Client, get_parameters_msg: ServerMessage.GetParametersIns
+) -> ClientMessage:
+    # Check if client overrides get_parameters
+    if not has_get_parameters(client=client):
+        # If client does not override get_parameters, don't call it
+        get_parameters_res = typing.GetParametersRes(
+            status=typing.Status(
+                code=typing.Code.GET_PARAMETERS_NOT_IMPLEMENTED,
+                message="Client does not implement `get_parameters`",
+            ),
+            parameters=Parameters(tensor_type="", tensors=[]),
+        )
+        get_parameters_res_proto = serde.get_parameters_res_to_proto(get_parameters_res)
+        return ClientMessage(get_parameters_res=get_parameters_res_proto)
+
+    # Deserialize get_properties instruction
+    get_parameters_ins = serde.get_parameters_ins_from_proto(get_parameters_msg)
+    # Request parameters
+    get_parameters_res = client.get_parameters(get_parameters_ins)
+    # Serialize response
+    get_parameters_res_proto = serde.get_parameters_res_to_proto(get_parameters_res)
+    return ClientMessage(get_parameters_res=get_parameters_res_proto)
 
 
 def _fit(client: Client, fit_msg: ServerMessage.FitIns) -> ClientMessage:
+    # Check if client overrides fit
+    if not has_fit(client=client):
+        # If client does not override fit, don't call it
+        fit_res = typing.FitRes(
+            status=typing.Status(
+                code=typing.Code.FIT_NOT_IMPLEMENTED,
+                message="Client does not implement `fit`",
+            ),
+            parameters=Parameters(tensor_type="", tensors=[]),
+            num_examples=0,
+            metrics={},
+        )
+        fit_res_proto = serde.fit_res_to_proto(fit_res)
+        return ClientMessage(fit_res=fit_res_proto)
+
     # Deserialize fit instruction
     fit_ins = serde.fit_ins_from_proto(fit_msg)
     # Perform fit
@@ -121,6 +161,21 @@ def _fit(client: Client, fit_msg: ServerMessage.FitIns) -> ClientMessage:
 
 
 def _evaluate(client: Client, evaluate_msg: ServerMessage.EvaluateIns) -> ClientMessage:
+    # Check if client overrides evaluate
+    if not has_evaluate(client=client):
+        # If client does not override evaluate, don't call it
+        evaluate_res = typing.EvaluateRes(
+            status=typing.Status(
+                code=typing.Code.EVALUATE_NOT_IMPLEMENTED,
+                message="Client does not implement `evaluate`",
+            ),
+            loss=0.0,
+            num_examples=0,
+            metrics={},
+        )
+        evaluate_res_proto = serde.evaluate_res_to_proto(evaluate_res)
+        return ClientMessage(evaluate_res=evaluate_res_proto)
+
     # Deserialize evaluate instruction
     evaluate_ins = serde.evaluate_ins_from_proto(evaluate_msg)
     # Perform evaluation
