@@ -12,17 +12,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
-"""Flower Server."""
+"""Flower server."""
 
 
+from .app import ServerConfig as ServerConfig
 from .app import start_server as start_server
+from .client_manager import ClientManager as ClientManager
 from .client_manager import SimpleClientManager as SimpleClientManager
 from .history import History as History
 from .server import Server as Server
 
 __all__ = [
-    "start_server",
-    "SimpleClientManager",
+    "ClientManager",
+    "ServerConfig",
     "History",
     "Server",
+    "SimpleClientManager",
+    "start_server",
 ]
