@@ -16,8 +16,8 @@
 
 
 from dataclasses import dataclass
-from logging import INFO
-from typing import Dict, Optional, Tuple, Union
+from logging import INFO, WARN
+from typing import Optional, Tuple
 
 from flwr.common import GRPC_MAX_MESSAGE_LENGTH
 from flwr.common.logger import log
@@ -31,10 +31,10 @@ DEFAULT_SERVER_ADDRESS = "[::]:8080"
 
 
 @dataclass
-class Config:
-    """Internal Flower server config.
+class ServerConfig:
+    """Flower server config.
 
-    All attributes have default values which allows users to provide
+    All attributes have default values which allows users to configure
     just the ones they care about.
     """
 
@@ -43,13 +43,13 @@ class Config:
 
 
 def start_server(  # pylint: disable=too-many-arguments
+    *,
     server_address: str = DEFAULT_SERVER_ADDRESS,
     server: Optional[Server] = None,
-    config: Optional[Dict[str, Union[int, Optional[float]]]] = None,
+    config: Optional[ServerConfig] = None,
     strategy: Optional[Strategy] = None,
     client_manager: Optional[ClientManager] = None,
     grpc_max_message_length: int = GRPC_MAX_MESSAGE_LENGTH,
-    force_final_distributed_eval: bool = False,
     certificates: Optional[Tuple[bytes, bytes, bytes]] = None,
 ) -> History:
     """Start a Flower server using the gRPC transport layer.
@@ -61,12 +61,9 @@ def start_server(  # pylint: disable=too-many-arguments
         server: Optional[flwr.server.Server] (default: None). An implementation
             of the abstract base class `flwr.server.Server`. If no instance is
             provided, then `start_server` will create one.
-        config: Optional[Dict[str, Union[int, Optional[float]]]] (default: None).
+        config: ServerConfig (default: None).
             Currently supported values are `num_rounds` (int, default: 1) and
-            `round_timeout` in seconds (float, default: None), so a full configuration
-            object instructing the server to perform three rounds of federated
-            learning with a round timeout of 10min looks like the following:
-            `{"num_rounds": 3, "round_timeout": 600.0}`.
+            `round_timeout` in seconds (float, default: None).
         strategy: Optional[flwr.server.Strategy] (default: None). An
             implementation of the abstract base class `flwr.server.Strategy`.
             If no strategy is provided, then `start_server` will use
@@ -82,9 +79,6 @@ def start_server(  # pylint: disable=too-many-arguments
             value. Note that the Flower clients need to be started with the
             same value (see `flwr.client.start_client`), otherwise clients will
             not know about the increased limit and block larger messages.
-        force_final_distributed_eval: bool (default: False).
-            Forces a distributed evaluation to occur after the last training
-            epoch when enabled.
         certificates : Tuple[bytes, bytes, bytes] (default: None)
             Tuple containing root certificate, server certificate, and private key to
             start a secure SSL-enabled server. The tuple is expected to have three bytes
@@ -114,12 +108,19 @@ def start_server(  # pylint: disable=too-many-arguments
     >>>     )
     >>> )
     """
+
+    # Initialize server and server config
     initialized_server, initialized_config = _init_defaults(
         server=server,
         config=config,
         strategy=strategy,
         client_manager=client_manager,
     )
+    log(
+        INFO,
+        "Starting Flower server, config: %s",
+        initialized_config,
+    )
 
     # Start gRPC server
     grpc_server = start_grpc_server(
@@ -128,15 +129,17 @@ def start_server(  # pylint: disable=too-many-arguments
         max_message_length=grpc_max_message_length,
         certificates=certificates,
     )
-    num_rounds = initialized_config.num_rounds
-    ssl_status = "enabled" if certificates is not None else "disabled"
-    msg = f"Flower server running ({num_rounds} rounds), SSL is {ssl_status}"
-    log(INFO, msg)
+    log(
+        INFO,
+        "Flower ECE: gRPC server running (%s rounds), SSL is %s",
+        initialized_config.num_rounds,
+        "enabled" if certificates is not None else "disabled",
+    )
 
+    # Start training
     hist = _fl(
         server=initialized_server,
         config=initialized_config,
-        force_final_distributed_eval=force_final_distributed_eval,
     )
 
     # Stop the gRPC server
@@ -147,10 +150,10 @@ def start_server(  # pylint: disable=too-many-arguments
 
 def _init_defaults(
     server: Optional[Server],
-    config: Optional[Dict[str, Union[int, Optional[float]]]],
+    config: Optional[ServerConfig],
     strategy: Optional[Strategy],
     client_manager: Optional[ClientManager],
-) -> Tuple[Server, Config]:
+) -> Tuple[Server, ServerConfig]:
     # Create server instance if none was given
     if server is None:
         if client_manager is None:
@@ -158,20 +161,19 @@ def _init_defaults(
         if strategy is None:
             strategy = FedAvg()
         server = Server(client_manager=client_manager, strategy=strategy)
+    elif strategy is not None:
+        log(WARN, "Both server and strategy were provided, ignoring strategy")
 
     # Set default config values
     if config is None:
-        config = {}
+        config = ServerConfig()
 
-    conf = Config(**config)  # type: ignore
-
-    return server, conf
+    return server, config
 
 
 def _fl(
     server: Server,
-    config: Config,
-    force_final_distributed_eval: bool,
+    config: ServerConfig,
 ) -> History:
     # Fit model
     hist = server.fit(num_rounds=config.num_rounds, timeout=config.round_timeout)
@@ -180,24 +182,6 @@ def _fl(
     log(INFO, "app_fit: losses_centralized %s", str(hist.losses_centralized))
     log(INFO, "app_fit: metrics_centralized %s", str(hist.metrics_centralized))
 
-    if force_final_distributed_eval:
-        # Temporary workaround to force distributed evaluation
-        server.strategy.eval_fn = None  # type: ignore
-
-        # Evaluate the final trained model
-        res = server.evaluate_round(rnd=-1, timeout=config.round_timeout)
-        if res is not None:
-            loss, _, (results, failures) = res
-            log(INFO, "app_evaluate: federated loss: %s", str(loss))
-            log(
-                INFO,
-                "app_evaluate: results %s",
-                str([(res[0].cid, res[1]) for res in results]),
-            )
-            log(INFO, "app_evaluate: failures %s", str(failures))
-        else:
-            log(INFO, "app_evaluate: no evaluation result")
-
     # Graceful shutdown
     server.disconnect_all_clients(timeout=config.round_timeout)
 
