@@ -19,7 +19,7 @@ Paper: https://arxiv.org/abs/1602.05629
 """
 
 
-from typing import Callable, Dict, List, Optional, Tuple, cast
+from typing import Callable, Dict, List, Optional, Tuple, Union, cast
 
 import numpy as np
 
@@ -28,9 +28,10 @@ from flwr.common import (
     EvaluateRes,
     FitIns,
     FitRes,
+    NDArray,
+    NDArrays,
     Parameters,
     Scalar,
-    Weights,
 )
 from flwr.server.client_manager import ClientManager
 from flwr.server.client_proxy import ClientProxy
@@ -45,13 +46,17 @@ class FedAvgAndroid(Strategy):
     # pylint: disable=too-many-arguments,too-many-instance-attributes
     def __init__(
         self,
-        fraction_fit: float = 0.1,
-        fraction_eval: float = 0.1,
+        *,
+        fraction_fit: float = 1.0,
+        fraction_evaluate: float = 1.0,
         min_fit_clients: int = 2,
-        min_eval_clients: int = 2,
+        min_evaluate_clients: int = 2,
         min_available_clients: int = 2,
-        eval_fn: Optional[
-            Callable[[Weights], Optional[Tuple[float, Dict[str, Scalar]]]]
+        evaluate_fn: Optional[
+            Callable[
+                [int, NDArrays, Dict[str, Scalar]],
+                Optional[Tuple[float, Dict[str, Scalar]]],
+            ]
         ] = None,
         on_fit_config_fn: Optional[Callable[[int], Dict[str, Scalar]]] = None,
         on_evaluate_config_fn: Optional[Callable[[int], Dict[str, Scalar]]] = None,
@@ -62,34 +67,42 @@ class FedAvgAndroid(Strategy):
 
         Implementation based on https://arxiv.org/abs/1602.05629
 
-        Args:
-            fraction_fit (float, optional): Fraction of clients used during
-                training. Defaults to 0.1.
-            fraction_eval (float, optional): Fraction of clients used during
-                validation. Defaults to 0.1.
-            min_fit_clients (int, optional): Minimum number of clients used
-                during training. Defaults to 2.
-            min_eval_clients (int, optional): Minimum number of clients used
-                during validation. Defaults to 2.
-            min_available_clients (int, optional): Minimum number of total
-                clients in the system. Defaults to 2.
-            eval_fn : Callable[[Weights], Optional[Tuple[float, Dict[str, Scalar]]]]
-                Optional function used for validation. Defaults to None.
-            on_fit_config_fn (Callable[[int], Dict[str, Scalar]], optional):
-                Function used to configure training. Defaults to None.
-            on_evaluate_config_fn (Callable[[int], Dict[str, Scalar]], optional):
-                Function used to configure validation. Defaults to None.
-            accept_failures (bool, optional): Whether or not accept rounds
-                containing failures. Defaults to True.
-            initial_parameters (Parameters, optional): Initial global model parameters.
+        Parameters
+        ----------
+        fraction_fit : Optional[float]
+            Fraction of clients used during training. Defaults to 0.1.
+        fraction_evaluate : Optional[float]
+            Fraction of clients used during validation. Defaults to 0.1.
+        min_fit_clients : Optional[int]
+            Minimum number of clients used during training. Defaults to 2.
+        min_evaluate_clients : Optional[int]
+            Minimum number of clients used during validation. Defaults to 2.
+        min_available_clients : Optional[int]
+            Minimum number of total clients in the system. Defaults to 2.
+        evaluate_fn : Optional[
+            Callable[
+                [int, NDArrays, Dict[str, Scalar]],
+                Optional[Tuple[float, Dict[str, Scalar]]]
+            ]
+        ]
+            Optional function used for validation. Defaults to None.
+        on_fit_config_fn : Optional[Callable[[int], Dict[str, Scalar]]]
+            Function used to configure training. Defaults to None.
+        on_evaluate_config_fn : Optional[Callable[[int], Dict[str, Scalar]]]
+            Function used to configure validation. Defaults to None.
+        accept_failures : Optional[bool]
+            Whether or not accept rounds
+            containing failures. Defaults to True.
+        initial_parameters : Optional[Parameters]
+            Initial global model parameters.
         """
         super().__init__()
         self.min_fit_clients = min_fit_clients
-        self.min_eval_clients = min_eval_clients
+        self.min_evaluate_clients = min_evaluate_clients
         self.fraction_fit = fraction_fit
-        self.fraction_eval = fraction_eval
+        self.fraction_evaluate = fraction_evaluate
         self.min_available_clients = min_available_clients
-        self.eval_fn = eval_fn
+        self.evaluate_fn = evaluate_fn
         self.on_fit_config_fn = on_fit_config_fn
         self.on_evaluate_config_fn = on_evaluate_config_fn
         self.accept_failures = accept_failures
@@ -107,8 +120,8 @@ class FedAvgAndroid(Strategy):
 
     def num_evaluation_clients(self, num_available_clients: int) -> Tuple[int, int]:
         """Use a fraction of available clients for evaluation."""
-        num_clients = int(num_available_clients * self.fraction_eval)
-        return max(num_clients, self.min_eval_clients), self.min_available_clients
+        num_clients = int(num_available_clients * self.fraction_evaluate)
+        return max(num_clients, self.min_evaluate_clients), self.min_available_clients
 
     def initialize_parameters(
         self, client_manager: ClientManager
@@ -119,27 +132,27 @@ class FedAvgAndroid(Strategy):
         return initial_parameters
 
     def evaluate(
-        self, parameters: Parameters
+        self, server_round: int, parameters: Parameters
     ) -> Optional[Tuple[float, Dict[str, Scalar]]]:
         """Evaluate model parameters using an evaluation function."""
-        if self.eval_fn is None:
+        if self.evaluate_fn is None:
             # No evaluation function provided
             return None
-        weights = self.parameters_to_weights(parameters)
-        eval_res = self.eval_fn(weights)
+        weights = self.parameters_to_ndarrays(parameters)
+        eval_res = self.evaluate_fn(server_round, weights, {})
         if eval_res is None:
             return None
         loss, metrics = eval_res
         return loss, metrics
 
     def configure_fit(
-        self, rnd: int, parameters: Parameters, client_manager: ClientManager
+        self, server_round: int, parameters: Parameters, client_manager: ClientManager
     ) -> List[Tuple[ClientProxy, FitIns]]:
         """Configure the next round of training."""
         config = {}
         if self.on_fit_config_fn is not None:
             # Custom fit config function provided
-            config = self.on_fit_config_fn(rnd)
+            config = self.on_fit_config_fn(server_round)
         fit_ins = FitIns(parameters, config)
 
         # Sample clients
@@ -154,39 +167,36 @@ class FedAvgAndroid(Strategy):
         return [(client, fit_ins) for client in clients]
 
     def configure_evaluate(
-        self, rnd: int, parameters: Parameters, client_manager: ClientManager
+        self, server_round: int, parameters: Parameters, client_manager: ClientManager
     ) -> List[Tuple[ClientProxy, EvaluateIns]]:
         """Configure the next round of evaluation."""
-        # Do not configure federated evaluation if fraction_eval is 0
-        if self.fraction_eval == 0.0:
+        # Do not configure federated evaluation if fraction_evaluate is 0
+        if self.fraction_evaluate == 0.0:
             return []
 
         # Parameters and config
         config = {}
         if self.on_evaluate_config_fn is not None:
             # Custom evaluation config function provided
-            config = self.on_evaluate_config_fn(rnd)
+            config = self.on_evaluate_config_fn(server_round)
         evaluate_ins = EvaluateIns(parameters, config)
 
         # Sample clients
-        if rnd >= 0:
-            sample_size, min_num_clients = self.num_evaluation_clients(
-                client_manager.num_available()
-            )
-            clients = client_manager.sample(
-                num_clients=sample_size, min_num_clients=min_num_clients
-            )
-        else:
-            clients = list(client_manager.all().values())
+        sample_size, min_num_clients = self.num_evaluation_clients(
+            client_manager.num_available()
+        )
+        clients = client_manager.sample(
+            num_clients=sample_size, min_num_clients=min_num_clients
+        )
 
         # Return client/config pairs
         return [(client, evaluate_ins) for client in clients]
 
     def aggregate_fit(
         self,
-        rnd: int,
+        server_round: int,
         results: List[Tuple[ClientProxy, FitRes]],
-        failures: List[BaseException],
+        failures: List[Union[Tuple[ClientProxy, FitRes], BaseException]],
     ) -> Tuple[Optional[Parameters], Dict[str, Scalar]]:
         """Aggregate fit results using weighted average."""
         if not results:
@@ -196,16 +206,16 @@ class FedAvgAndroid(Strategy):
             return None, {}
         # Convert results
         weights_results = [
-            (self.parameters_to_weights(fit_res.parameters), fit_res.num_examples)
+            (self.parameters_to_ndarrays(fit_res.parameters), fit_res.num_examples)
             for client, fit_res in results
         ]
-        return self.weights_to_parameters(aggregate(weights_results)), {}
+        return self.ndarrays_to_parameters(aggregate(weights_results)), {}
 
     def aggregate_evaluate(
         self,
-        rnd: int,
+        server_round: int,
         results: List[Tuple[ClientProxy, EvaluateRes]],
-        failures: List[BaseException],
+        failures: List[Union[Tuple[ClientProxy, EvaluateRes], BaseException]],
     ) -> Tuple[Optional[float], Dict[str, Scalar]]:
         """Aggregate evaluation losses using weighted average."""
         if not results:
@@ -221,22 +231,22 @@ class FedAvgAndroid(Strategy):
         )
         return loss_aggregated, {}
 
-    def weights_to_parameters(self, weights: Weights) -> Parameters:
-        """Convert NumPy weights to parameters object."""
-        tensors = [self.ndarray_to_bytes(ndarray) for ndarray in weights]
+    def ndarrays_to_parameters(self, ndarrays: NDArrays) -> Parameters:
+        """Convert NumPy ndarrays to parameters object."""
+        tensors = [self.ndarray_to_bytes(ndarray) for ndarray in ndarrays]
         return Parameters(tensors=tensors, tensor_type="numpy.nda")
 
-    def parameters_to_weights(self, parameters: Parameters) -> Weights:
+    def parameters_to_ndarrays(self, parameters: Parameters) -> NDArrays:
         """Convert parameters object to NumPy weights."""
         return [self.bytes_to_ndarray(tensor) for tensor in parameters.tensors]
 
     # pylint: disable=R0201
-    def ndarray_to_bytes(self, ndarray: np.ndarray) -> bytes:
+    def ndarray_to_bytes(self, ndarray: NDArray) -> bytes:
         """Serialize NumPy array to bytes."""
         return ndarray.tobytes()
 
     # pylint: disable=R0201
-    def bytes_to_ndarray(self, tensor: bytes) -> np.ndarray:
+    def bytes_to_ndarray(self, tensor: bytes) -> NDArray:
         """Deserialize NumPy array from bytes."""
-        ndarray_deserialized = np.frombuffer(tensor, dtype=np.float32)
-        return cast(np.ndarray, ndarray_deserialized)
+        ndarray_deserialized = np.frombuffer(tensor, dtype=np.float32)  # type: ignore
+        return cast(NDArray, ndarray_deserialized)
